@@ -1,13 +1,15 @@
-from pyorthanc.orthanc import Orthanc
+from pyorthanc.async_client import AsyncOrthanc
+from pyorthanc.client import Orthanc
 from pyorthanc.remote import RemoteModality
 from pyorthanc.patient import Patient
 from pyorthanc.study import Study
 from pyorthanc.series import Series
 from pyorthanc.instance import Instance
-from pyorthanc.util import build_patient_forest, trim_patient_forest, \
-    retrieve_and_write_patients
+from pyorthanc.filtering import build_patient_forest, find, trim_patient, retrieve_and_write_patients
+
 
 __all__ = [
+    'AsyncOrthanc',
     'Orthanc',
     'RemoteModality',
     'Patient',
@@ -15,6 +17,7 @@ __all__ = [
     'Series',
     'Instance',
     'build_patient_forest',
-    'trim_patient_forest',
-    'retrieve_and_write_patients'
+    'trim_patient',
+    'retrieve_and_write_patients',
+    'find',
 ]
